pub fn render_text(text: &str, font: VectorFont) -> Vec<Point>Expand description
Render the given text string to a list of points using the specified font.
pub fn render_text(text: &str, font: VectorFont) -> Vec<Point>Render the given text string to a list of points using the specified font.